@@ -4,7 +4,7 @@ use 5.006002;
 use strict;
 use warnings;
 
-our $VERSION = '1.039';
+our $VERSION = '1.040';
 
 my %introduces = do { no warnings 'qw';
                  ( '5.040' => [qw[
@@ -302,7 +302,7 @@ Syntax::Construct - Explicitly state which non-feature constructs are used in th
 
 =head1 VERSION
 
-Version 1.039
+Version 1.040
 
 =head1 SYNOPSIS
 
@@ -970,7 +970,7 @@ Alias: logical-xor
 
 =head3 __CLASS__
 
-L<perl5400delta/New __CLASS__ keyword>.
+L<perl5400delta/New __CLASS__ Keyword>.
 
 =head3 :reader
 
